@@ -11,6 +11,25 @@ require DynaLoader;
 
 our @ISA = qw(Exporter DynaLoader);
 
+# Original script written by Michael Larsen, larsen@edu.upenn.math
+# Modified by Martin Ward, martin@gkc.org.uk
+# Copyright 1994 Michael Larsen and Martin Ward
+# Email: martin@gkc.org.uk
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
@@ -30,7 +49,7 @@ our @EXPORT = qw(
 	
 );
 
-$Text::Reflow::VERSION = "1.06";
+$Text::Reflow::VERSION = "1.07";
 
 bootstrap Text::Reflow $Text::Reflow::VERSION;
 
@@ -626,7 +645,6 @@ sub compute_output {
 
 1;
 __END__
-# Below is stub documentation for your module. You better edit it!
 
 =head1 NAME
 
@@ -812,7 +830,7 @@ None by default.
 Original C<reflow> perl script written by Michael Larsen, larsen@edu.upenn.math.
 
 Modified, enhanced and converted to a perl module with XSUB
-by Martin Ward, Martin.Ward@durham.ac.uk
+by Martin Ward, martin@gkc.org.uk
 
 =head1 SEE ALSO
 
